@@ -47,15 +47,45 @@ impl<'a> DeleteOriginalResponse<'a> {
         }
     }
 
+    fn request(&self) -> Request {
+        Request::builder(&Route::DeleteInteractionOriginal {
+            application_id: self.application_id.get(),
+            interaction_token: self.token,
+        })
+        .use_authorization_token(false)
+        .build()
+    }
+
     /// Execute the request, returning a future resolving to a [`Response`].
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let request = Request::from_route(&Route::DeleteInteractionOriginal {
-            application_id: self.application_id.get(),
-            interaction_token: self.token,
-        });
+        self.http.request(self.request())
+    }
+}
 
-        self.http.request(request)
+#[cfg(test)]
+mod tests {
+    use crate::client::Client;
+    use std::error::Error;
+    use twilight_http_ratelimiting::Path;
+    use twilight_model::id::ApplicationId;
+
+    #[test]
+    fn test_delete_followup_message() -> Result<(), Box<dyn Error>> {
+        let application_id = ApplicationId::new(1).expect("non zero id");
+        let token = "foo".to_owned().into_boxed_str();
+
+        let client = Client::new(String::new());
+        client.set_application_id(application_id);
+        let req = client.delete_interaction_original(&token)?.request();
+
+        assert!(!req.use_authorization_token());
+        assert_eq!(
+            &Path::WebhooksIdTokenMessagesId(application_id.get(), token),
+            req.ratelimit_path()
+        );
+
+        Ok(())
     }
 }
