@@ -31,8 +31,8 @@ impl<'a> AddThreadMember<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
         let request = Request::from_route(&Route::AddThreadMember {
-            channel_id: self.channel_id.0,
-            user_id: self.user_id.0,
+            channel_id: self.channel_id.get(),
+            user_id: self.user_id.get(),
         });
 
         self.http.request(request)
