@@ -1,7 +1,7 @@
 use crate::{client::Client, request::Request, response::ResponseFuture, routing::Route};
 use twilight_model::{
     channel::Message,
-    id::{MessageId, WebhookId},
+    id::{ChannelId, MessageId, WebhookId},
 };
 
 /// Get a webhook message by [`WebhookId`], token, and [`MessageId`].
@@ -12,6 +12,7 @@ use twilight_model::{
 pub struct GetWebhookMessage<'a> {
     http: &'a Client,
     message_id: MessageId,
+    thread_id: Option<ChannelId>,
     token: &'a str,
     webhook_id: WebhookId,
 }
@@ -26,17 +27,27 @@ impl<'a> GetWebhookMessage<'a> {
         Self {
             http,
             message_id,
+            thread_id: None,
             token,
             webhook_id,
         }
     }
 
+    /// Get a message in a thread belonging to the channel instead of the
+    /// channel itself.
+    pub fn thread_id(mut self, thread_id: ChannelId) -> Self {
+        self.thread_id.replace(thread_id);
+
+        self
+    }
+
     /// Execute the request, returning a future resolving to a [`Response`].
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Message> {
         let request = Request::builder(&Route::GetWebhookMessage {
             message_id: self.message_id.get(),
+            thread_id: self.thread_id.map(ChannelId::get),
             token: self.token,
             webhook_id: self.webhook_id.get(),
         })
