@@ -256,7 +256,7 @@ impl<'a> CreateGuildChannel<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<GuildChannel> {
         let mut request = Request::builder(&Route::CreateChannel {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         request = match request.json(&self.fields) {
