@@ -25,7 +25,7 @@ impl<'a> GetGuildVoiceRegions<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<VoiceRegion>> {
         let request = Request::from_route(&Route::GetGuildVoiceRegions {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
